Package: rasciidoc
Title: Create Reports Using R and 'asciidoc'
Version: 4.1.1
Authors@R: 
    person(given = "Andreas Dominik",
           family = "Cullmann",
           role = c("aut", "cre"),
           email = "fvafrcu@mailbox.org")
Description: Inspired by Karl Broman`s reader on using 'knitr'
    with 'asciidoc'
    (<https://kbroman.org/knitr_knutshell/pages/asciidoc.html>), this is
    merely a wrapper to 'knitr' and 'asciidoc'.
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrcu/rasciidoc
Depends: R (>= 3.3.0)
Imports: checkmate, fritools (>= 3.7.1), gert, highr, knitr,
        reticulate, tools
Suggests: devtools, pkgload, rmarkdown, rprojroot, RUnit, testthat,
        withr
Encoding: UTF-8
RoxygenNote: 7.2.3
SystemRequirements: python >= 2.6, by default rasciidoc uses a system
        installation of asciidoc. If a system installation of asciidoc
        is not available, it downloads the sources from
        (<http://gitlab.com/asciidoc>). GNU source-highlight is
        recommended.
VignetteBuilder: rasciidoc
NeedsCompilation: no
Packaged: 2023-08-15 21:58:49 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2023-08-15 22:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:43:05 UTC; unix
