---
title: Some Title
author: Your Name
---

= What is this About?

This will not show up on slides.

== Some simple asciidoc

* A list with a [link](https://en.wikipedia.org/wiki/Hyperlink).
* Yet another entry in the list.

= Including Code
Do not use the _include_ macro provided by asciidoc! 
``` {r, code = readLines("src/sum.R")}
``` 

= A new section
``` {r, code = readLines("src/my_sum.R")}
``` 

= Only sections give new slides 
== A subsection
``` {r}
print(value)
``` 

``` {r}
print(my_sum(1:3))
``` 

Some inline code: Object `value` has value `r value`.

= Next slide 

== Second subsection
